Struct language_e2e_tests::account_universe::AccountCurrent [−][src]
pub struct AccountCurrent { /* fields omitted */ }Expand description
Represents the current state of account in a universe, possibly after its state has been updated by running transactions against the universe.
Implementations
Rotates the key in this account.
Returns the current balance for this account, assuming all transactions seen so far are applied.
Returns the current sequence number for this account, assuming all transactions seen so far are applied.
Returns the current sent events count for this account, assuming all transactions seen so far are applied.
Returns the current received events count for this account, assuming all transactions seen so far are applied.
Returns the gas cost of a create-account transaction.
Returns the gas cost of a create-account transaction where the sender has an insufficient balance.
Returns the gas cost of a create-account transaction where the account exists already.
Returns the gas cost of a peer-to-peer transaction.
Returns the gas cost of a peer-to-peer transaction with an insufficient balance.
Returns the gas cost of a create-account transaction where the account exists already.
Returns the gas cost of a create-account transaction where the account exists already.
Returns the gas cost of a peer-to-peer transaction with an insufficient balance.